@@ -55,6 +55,20 @@ func TestManagedCmd(t *testing.T) {
 				".file",
 			),
 		},
+		{
+			name: "remove",
+			root: map[string]any{
+				"/home/user": map[string]any{
+					".local/share/chezmoi/.chezmoiremove": chezmoitest.JoinLines(
+						".remove",
+					),
+					".remove": "",
+				},
+			},
+			expectedOutput: chezmoitest.JoinLines(
+				".remove",
+			),
+		},
 		{
 			name: "script_template",
 			root: map[string]any{
